@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::array::str_comma_sep;
 
 our $DATE = '2016-05-19'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -43,13 +43,13 @@ Data::Sah::Coerce::perl::array::str_comma_sep - Coerce array from a comma-separa
 
 =head1 VERSION
 
-This document describes version 0.001 of Data::Sah::Coerce::perl::array::str_comma_sep (from Perl distribution Data-Sah-CoerceRule-array-str_comma_sep), released on 2016-05-19.
+This document describes version 0.002 of Data::Sah::Coerce::perl::array::str_comma_sep (from Perl distribution Data-Sah-CoerceRule-array-str_comma_sep), released on 2016-05-19.
 
 =head1 DESCRIPTION
 
 The rule is not enabled by default. You can enable it in a schema using e.g.:
 
- ["array*", of=>"int", "x.coerce_from"=>"str_comma_sep"]
+ ["array*", of=>"int", "x.coerce_from"=>["str_comma_sep"]]
 
 =for Pod::Coverage ^(meta|coerce)$
 
